@@ -1,18 +1,5 @@
-/*
- * Copyright (C) 2012 Jean-Christophe PLAGNIOL-VILLARD <plagnioj@jcrosoft.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- *
- */
+// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-FileCopyrightText: 2012 Jean-Christophe PLAGNIOL-VILLARD <plagnioj@jcrosoft.com>
 
 #include <common.h>
 #include <net.h>
@@ -408,7 +395,7 @@ static void ek_add_device_hdmi(void)
 	hdmi_reset_start = get_time_ns();
 	hdmi_poller.func = hdmi_off_poller;
 
-	poller_register(&hdmi_poller);
+	poller_register(&hdmi_poller, "hdmi-reset");
 }
 #else
 static void ek_add_device_hdmi(void)
