@@ -22,6 +22,7 @@
 #include <led.h>
 #include <of.h>
 #include <restart.h>
+#include <linux/stringify.h>
 
 int errno;
 EXPORT_SYMBOL(errno);
@@ -29,7 +30,7 @@ EXPORT_SYMBOL(errno);
 
 const char *strerror(int errnum)
 {
-	static char errno_string[10];
+	static char errno_string[sizeof("error -2147483648")];
 
 #ifdef CONFIG_ERRNO_MESSAGES
 	char *str;
@@ -154,7 +155,7 @@ const char *barebox_get_model(void)
 }
 EXPORT_SYMBOL(barebox_get_model);
 
-BAREBOX_MAGICVAR_NAMED(global_model, global.model, "Product name of this hardware");
+BAREBOX_MAGICVAR(global.model, "Product name of this hardware");
 
 static char *hostname;
 
@@ -184,7 +185,7 @@ void barebox_set_hostname_no_overwrite(const char *__hostname)
 }
 EXPORT_SYMBOL(barebox_set_hostname_no_overwrite);
 
-BAREBOX_MAGICVAR_NAMED(global_hostname, global.hostname,
+BAREBOX_MAGICVAR(global.hostname,
 		"shortname of the board. Also used as hostname for DHCP requests");
 
 void __noreturn panic(const char *fmt, ...)
